==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/gradle/project/sync/setup/post/PluginVersionUpgradeStep.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.setup.post;

import com.android.tools.idea.gradle.plugin.AndroidPluginInfo;
import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;

public abstract class PluginVersionUpgradeStep {
  private static final ExtensionPointName<PluginVersionUpgradeStep>
    EXTENSION_POINT_NAME = ExtensionPointName.create("com.android.gradle.sync.pluginVersionUpgradeStep");

  @NotNull
  public static PluginVersionUpgradeStep[] getExtensions() {
    return EXTENSION_POINT_NAME.getExtensions();
  }

  /**
   * Checks if the Android plugin used in a project needs to be upgraded, and if so, performs the upgrade.
   *
   * @param project    the current project.
   * @param pluginInfo information about the Android plugin used in the project.
   * @return {@code true} if an upgrade was needed and was successfully performed; {@code false} otherwise.
   */
  public abstract boolean checkAndPerformUpgrade(@NotNull Project project, @NotNull AndroidPluginInfo pluginInfo);
}

==> ideaIC-2019.2.1-sources.jar: com/android/tools/idea/gradle/project/sync/setup/post/PluginVersionUpgradeStep.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.setup.post;

import com.android.tools.idea.gradle.plugin.AndroidPluginInfo;
import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;

public abstract class PluginVersionUpgradeStep {
  public static final ExtensionPointName<PluginVersionUpgradeStep>
    EXTENSION_POINT_NAME = ExtensionPointName.create("com.android.gradle.sync.pluginVersionUpgradeStep");

  @NotNull
  public static PluginVersionUpgradeStep[] getExtensions() {
    return EXTENSION_POINT_NAME.getExtensions();
  }

  /**
   * Checks if the Android plugin used in a project needs to be upgraded, and if so, performs the upgrade.
   *
   * @param project    the current project.
   * @param pluginInfo information about the Android plugin used in the project.
   * @return {@code true} if an upgrade was needed and was successfully performed; {@code false} otherwise.
   */
  public abstract boolean checkAndPerformUpgrade(@NotNull Project project, @NotNull AndroidPluginInfo pluginInfo);
}
